@@ -606,7 +606,7 @@ class Calendar(Dict, _calendar):
 
         Parameters
         ----------
-        date : datetime
+        date : datetime or timeseries
             start date.
         days : int
             days to bump.
